EncodeChildren

Trait EncodeChildren 

pub trait EncodeChildren {
    type Error;

    // Required method
    fn encode_with_config(
        &self,
        config: &Config,
    ) -> Result<Vec<XMLNode>, Self::Error>;

    // Provided method
    fn encode(&self) -> Result<Vec<XMLNode>, Self::Error> { ... }
}
EncodeChildren allows SVD objects to be encoded as a list of XML nodes This is typically used to merge with an existing element.

Required Associated Types

type Error

Encoding error

Required Methods

fn encode_with_config( &self, config: &Config, ) -> Result<Vec<XMLNode>, Self::Error>

Encode into XML/SVD children to merge with existing object with a custom configuration

Provided Methods

fn encode(&self) -> Result<Vec<XMLNode>, Self::Error>

Encode into XML/SVD children to merge with existing object

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl EncodeChildren for RegisterProperties

Implementors